/*  libbadpenguin -- generic library for Bad Penguin development
 *
 *  Copyright (C) 1996 Antonio Gallo <agx@linux.it>
 *  
 *  Newer versions should be on www.badpenguin.org
 *
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2, or (at your option)
 * any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  
 */

/*
 * Bad Penguin ANSI utilities
 * for coloured and fancy terminal output
 * @1999 by Antonio Gallo
 */

#ifndef _BADPENGUIN_ANSI_H
#define _BADPENGUIN_ANSI_H

#include <stdio.h>

// Foreground Colors
#define FG_BLACK	"\033[2;30m"
#define FG_RED		"\033[1;31m"
#define FG_GREEN	"\033[1;32m"
#define FG_ORANGE	"\033[2;33m"
#define FG_YELLOW	"\033[1;33m"
#define FG_BLUE		"\033[1;34m"
#define FG_MAGENTA	"\033[1;35m"
#define FG_PURPLE	FG_MAGENTA
#define FG_CYAN		"\033[1;36m"
#define FG_SILVER	"\033[2;37m"
#define FG_WHITE	"\033[1;37m"

// Background Colors
#define BG_BLACK	"\033[40m"
#define BG_RED		"\033[41m"
#define BG_GREEN	"\033[42m"
#define BG_ORANGE	"\033[43m"
#define BG_BLUE		"\033[44m"
#define BG_MAGENTA	"\033[45m"
#define BG_CYAN		"\033[46m"
#define BG_WHITE	"\033[47m"

// Blink (not sure about blink off)
#define BLINK_ON	"\033[5m"
#define BLINK_OFF	"\033[2m"
#define BOLD_ON		"\033[1m"
#define BOLD_OFF	"\033[2m"
#define REVERSE_ON	"\033[7m"
#define ALL_OFF		"\033[0m"
#define BELL		"\007"
//#define RESET_TERM	"\033[0;10;39m"
#define RESET_TERM	"\033c"

// Misc
#define CURSOR_ON	"\033[?25h"
#define CURSOR_OFF	"\033[?25l"

// printf Macros
#define color(X)	printf("%s",(X))
#define printERROR	printf("%s",FG_RED);printf
#define printWARNING	printf("%s",FG_YELLOW);printf
#define printNOTICE	printf("%s",FG_PURPLE);printf
#define printSUCCESS	printf("%s",FG_GREEN);printf
#define printTITLE	printf("%s",FG_CYAN);printf
#define normal_color()  printf("%s%s", BOLD_ON, FG_SILVER)

#define ansi_goto(Y,X)	printf( "\033[%i;%iH", (Y), (X) )
#define ansi_color(X)	printf( "%s", (X) )
//#define ansi_clrscr()   printf( "\033[2J\033[0;0H" )
#define ansi_clrscr()   printf( "\033[H\033[J" )
/* title put string in RED/BLUE at 0,0 and perform a CLREOL */
#define ansi_title(X)   printf( "\033[0;31m\033[47m\033[0;0H"); printf("%s\033[K",X)

// Utils
void printCenter(char *s);

/* CURSOR MOVEMENT */
void ansi_move_home();
void ansi_move_lowerleft();
void ansi_move_up(int i);
void ansi_move_down(int i);
void ansi_move_right(int i);
void ansi_move_left(int i);
void ansi_push_cursor();
void ansi_pop_cursor();
void ansi_clreol();
void ansi_clreos();
void printBackTitle(char *s);

#endif
